@@ -115,7 +115,7 @@ class MeteobridgeApiClient:
                 data["relative_humidity"],
                 data["wind_gust"]
             )
-            beaufort_data: BeaufortDescription = self.cnv.beaufort(data["wind_avg"])
+            beaufort_data: BeaufortDescription = self.cnv.beaufort_value(data["wind_avg"])
             wet_bulb = self.cnv.wetbulb(
                 data["air_temperature"],
                 data["relative_humidity"],
@@ -131,6 +131,8 @@ class MeteobridgeApiClient:
                 station_pressure=self.cnv.pressure(data["station_pressure"]),
                 relative_humidity=data["relative_humidity"],
                 precip_accum_local_day=self.cnv.rain(data["precip_accum_local_day"]),
+                precip_accum_month=self.cnv.rain(data["precip_accum_month"]),
+                precip_accum_year=self.cnv.rain(data["precip_accum_year"]),
                 precip_rate=self.cnv.rain(data["precip_rate"]),
                 wind_avg=self.cnv.windspeed(data["wind_avg"]),
                 wind_gust=self.cnv.windspeed(data["wind_gust"]),
@@ -156,7 +158,8 @@ class MeteobridgeApiClient:
                 air_pm_10=data["air_pm_10"],
                 air_pm_25=data["air_pm_25"],
                 air_pm_1=data["air_pm_1"],
-                aqi=self.cnv.aqi(data["air_pm_25_havg"]),
+                aqi_level=self.cnv.aqi_level(data["air_pm_25_havg"]),
+                aqi=self.cnv.aqi_description(data["air_pm_25_havg"]),
                 forecast=data["forecast"],
                 indoor_temperature=self.cnv.temperature(data["indoor_temperature"]),
                 indoor_humidity=data["indoor_humidity"],
@@ -313,7 +316,7 @@ class MeteobridgeApiClient:
         method: str,
         endpoint: str,
     ) -> dict:
-        """Make a request against the SmartWeather API."""
+        """Make a request against the API."""
         use_running_session = self.req and not self.req.closed
 
         if use_running_session:
