@@ -31,6 +31,8 @@ class ObservationDescription:
     sea_level_pressure: float | None = None
     relative_humidity: int | None = None
     precip_accum_local_day: float | None = None
+    precip_accum_month: float | None = None
+    precip_accum_year: float | None = None
     precip_rate: float | None = None
     wind_avg: float | None = None
     wind_direction: int | None = None
@@ -57,7 +59,8 @@ class ObservationDescription:
     air_pm_10: float | None = None
     air_pm_25: float | None = None
     air_pm_1: float | None = None
-    aqi: int | None = None
+    aqi_level: int | None = None
+    aqi: str | None = None
     forecast: str | None = None
     indoor_temperature: float | None = None
     indoor_humidity: int | None = None
